@@ -5,6 +5,8 @@ import copy
 import itertools
 import re
 import time
+import uuid
+
 import yaml
 import traceback
 import os
@@ -32,6 +34,7 @@ from .generate import generate_req, generate_res, calculate_num, grouper
 
 @dataclass
 class RuntimeConstant:
+    test_id: str
     test_directory: str
     case_directory: str
     case_regex: str
@@ -96,6 +99,7 @@ class Framework:
 
         test_directory = test_directory.strip().rstrip("/") if test_directory else test_directory
         self.constant = RuntimeConstant(
+            test_id=uuid.uuid4().hex,
             test_directory=test_directory,
             case_directory=test_directory if not case_directory else os.path.join(test_directory, case_directory.strip().rstrip("/")),
             case_regex=case_regex,
@@ -175,7 +179,7 @@ class Framework:
         self.customize = json.loads(json.dumps(cfg["framework"]), object_hook=lambda y: SimpleNamespace(**y))
 
         self.reporter = self.reporter_map[reporter](cfg["reporter"][reporter])
-        self.hooks = [self.hook_map[i](cfg["hook"][i]) for i in hooks]
+        self.hooks = [self.hook_map[i](cfg["hook"][i], test_id=self.constant.test_id) for i in hooks]
 
         self.json_result = json_result
 
@@ -220,7 +224,7 @@ class Framework:
         try:
             result = Framework.run_test(directory, customize, constant, rctx)
         except Exception as e:
-            result = TestResult(directory, directory, "", "Exception {}".format(traceback.format_exc()))
+            result = TestResult(constant.test_id, directory, directory, "", "Exception {}".format(traceback.format_exc()))
         for hook in rctx.hooks:
             hook.on_test_end(result)
         return result
@@ -233,10 +237,10 @@ class Framework:
         parent_rctx: RuntimeContext,
     ):
         if constant.case_id and not (constant.case_directory + "/").startswith(directory + "/"):
-            return TestResult(directory, directory[len(constant.test_directory)+1:], "", is_skip=True)
+            return TestResult(constant.test_id, directory, directory[len(constant.test_directory)+1:], "", is_skip=True)
         if not (constant.case_directory + "/").startswith(directory + "/") and \
                 not (directory + "/").startswith(constant.case_directory + "/"):
-            return TestResult(directory, directory[len(constant.test_directory)+1:], "", is_skip=True)
+            return TestResult(constant.test_id, directory, directory[len(constant.test_directory)+1:], "", is_skip=True)
 
         now = datetime.now()
 
@@ -271,7 +275,7 @@ class Framework:
             ctx[key] = parent_rctx.driver_map[val["type"]](val["args"])
             dft[key] = val["dft"]
 
-        test_result = TestResult(directory, info["name"], description)
+        test_result = TestResult(constant.test_id, directory, info["name"], description)
 
         rctx = RuntimeContext(
             ctx=ctx,
