@@ -2,10 +2,10 @@
 
 
 from .include import *
-from .exec_with_res import exec_with_res
+from .exec_func import exec_with_res, exec_shell
 
 
-def render(req, case=None, var=None, x=None, peval="#", pexec="%"):
+def render(req, case=None, var=None, x=None, peval="#", pexec="%", pshell="$"):
     if isinstance(req, dict):
         res = {}
         for key, val in req.items():
@@ -13,6 +13,8 @@ def render(req, case=None, var=None, x=None, peval="#", pexec="%"):
                 res[key[len(peval):]] = eval(val)
             elif key.startswith(pexec):
                 res[key[len(pexec):]] = exec_with_res(val, case=case, var=var, x=x)
+            elif key.startswith(pshell):
+                res[key[len(pshell):]] = exec_shell(val)
             else:
                 res[key] = render(req[key], case=case, var=var, x=x)
         return res
